"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MediaGallery = exports.MediaInput = void 0;

var _react = _interopRequireDefault(require("react"));

var Dropzone = _interopRequireWildcard(require("react-dropzone-uploader"));

var _reactImageGallery = _interopRequireDefault(require("react-image-gallery"));

require("react-dropzone-uploader/dist/styles.css");

require("react-image-gallery/styles/css/image-gallery.css");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// created 2-feb-2020 by docker@instantlinux.net
function Headers() {
  return {
    Accept: 'application/json',
    'Content-Type': 'application/json',
    Authorization: 'Basic ' + btoa(sessionStorage.getItem('uid') + ':' + sessionStorage.getItem('token')),
    mode: 'no-cors'
  };
}

const MediaInput = props => {
  const storage_id = sessionStorage.getItem('storage_id');
  var mediaUrl = JSON.parse(sessionStorage.getItem('resource_endpoints'))['file'];

  const getUploadParams = async ({
    meta: {
      duration,
      height,
      lastModifiedDate,
      name,
      size,
      type,
      videoHeight,
      videoWidth,
      width
    }
  }) => {
    let params;

    if (['video/mp4', 'video/mpeg'].includes(type)) {
      params = {
        storage_id,
        content_type: type,
        duration,
        height: videoHeight,
        modified: lastModifiedDate,
        name,
        parent_id: props.parent_id,
        size,
        width: videoWidth
      };
    } else {
      params = {
        storage_id,
        content_type: type,
        height,
        modified: lastModifiedDate,
        name,
        parent_id: props.parent_id,
        size,
        width
      };
    }

    const api = await fetch(mediaUrl + '/file_upload_url', {
      body: JSON.stringify(params),
      headers: Headers(),
      method: 'POST'
    });
    const get_presigned = await api.json();
    return {
      fields: get_presigned.params,
      meta: {
        fileId: get_presigned.file_id
      },
      url: get_presigned.upload_url
    };
  };

  const handleChangeStatus = ({
    meta
  }, status) => {
    // console.log(status, meta)
    if (['aborted', 'done', 'error_upload'].includes(status)) {
      fetch(mediaUrl + '/upload_complete/' + meta.fileId + '?status=' + status, {
        headers: Headers(),
        method: 'POST'
      });
    }
  };

  const handleSubmit = (files, allFiles) => {
    // console.log(files.map(f => f.meta))
    allFiles.forEach(f => f.remove());
  };

  return (
    /*#__PURE__*/
    // TODO alternative to this .default syntax
    _react.default.createElement(Dropzone.default, {
      // eslint-disable-line
      getUploadParams: getUploadParams,
      inputContent: "Drop photos or click here",
      inputWithFilesContent: "Add another  ",
      maxFiles: 10,
      maxSizeBytes: 31457280,
      minSizeBytes: 1024,
      multiple: true,
      onChangeStatus: handleChangeStatus,
      onSubmit: handleSubmit,
      styles: {
        dropzone: {
          minHeight: 200,
          maxHeight: 250
        }
      },
      accept: "image/*,video/*"
    })
  );
};

exports.MediaInput = MediaInput;

class GalleryView extends _react.default.Component {
  // This class exists solely to fetch media before displaying
  // ImageGallery; dataProvider only has the album record, not
  // the media details
  constructor(props) {
    super(props);
    this.state = {
      album_id: props.id,
      isLoading: true,
      media: [],
      mediaUrl: JSON.parse(sessionStorage.getItem('resource_endpoints'))['file'],
      error: null
    };
  }

  componentDidMount() {
    fetch(this.state.mediaUrl + '/album/' + this.state.album_id + '?details=true', {
      headers: Headers()
    }).then(response => {
      if (response.ok) {
        return response.json();
      } else {
        throw new Error("error=".concat(response.json().message, " status=").concat(response.status));
      }
    }).then(data => this.setState({
      isLoading: false,
      media: data.media
    })).catch(error => this.setState({
      error,
      isLoading: false
    }));
  }

  render() {
    const {
      isLoading,
      media,
      error
    } = this.state;

    if (error) {
      return /*#__PURE__*/_react.default.createElement("span", null, error.message);
    }

    if (isLoading) {
      return /*#__PURE__*/_react.default.createElement("span", null, "Loading");
    } else {
      return /*#__PURE__*/_react.default.createElement(_reactImageGallery.default, {
        items: media,
        thumbnailPosition: "right",
        showIndex: true
      });
    }
  }

}

const MediaGallery = ({
  record
}) => {
  return /*#__PURE__*/_react.default.createElement(GalleryView, {
    id: record.id
  });
};

exports.MediaGallery = MediaGallery;