"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validatePasswordOK = exports.validateRequired4096String = exports.validateRequired255String = exports.validateRequired128String = exports.validateRequired96String = exports.validateRequired32String = exports.validate255String = exports.validate64String = exports.validate32String = exports.validateSelected = exports.validateNumMax = exports.validatePositive = exports.validateNameShort = exports.validateNameGeneral = exports.validateName = exports.validateUsername = exports.validateKeywordAlpha = exports.validateInteger = exports.validateURI = exports.validateEmail = exports.validateCountry = void 0;

var _reactAdmin = require("react-admin");

// Forms validation functions
// created 1-may-2019 by docker@instantlinux.net
const hasSelection = (message = 'ra.validation.required') => value => value == null ? message : undefined;

const isNameOK = (message = 'Alphanumeric or _&.- characters') => value => value.match(/^[a-zA-Z0-9]+[a-zA-Z0-9 _&.-]*$/) ? undefined : message;

const isKeywordAlphaNumeric = (message = 'Alphanumeric or _+@. characters') => value => value.match(/^[a-zA-Z]+[a-zA-Z0-9_+@.]*$/) ? undefined : message;

const isKeywordAlphaNumericLC = (message = 'Lowercase/numeric or _-. characters') => value => value.match(/^[a-z]+[a-z0-9_.-]*$/) ? undefined : message;

const isCountryCode = (message = 'Use uppercase') => value => value != null && value.match(/^[A-Z][A-Z]$/) ? undefined : message;

const isURI = (message = 'URI format') => value => value && !value.match(/^https?:\/\/[a-zA-Z0-9+_=/.-]{1,56}$/) ? message : undefined;

const hasComplexity = (message = 'Must have upper, lower, and symbol chars') => value => value != null && !(value.match(/[A-Z]+/) && value.match(/[a-z]+/) && value.match(/[@~!#%^&*+=';,{}[|":<>?/\\\].]+/)) ? message : undefined;

const isBlankorMin4Upto32 = (message = 'Between 4 and 32 characters') => value => value && (value.length < 4 || value.length > 32) ? message : undefined;

const isBlankorUpto64 = (message = 'Between 2 and 64 characters') => value => value && (value.length < 2 || value.length > 64) ? message : undefined;

const isBlankorUpto255 = (message = 'Between 8 and 255 characters') => value => value && (value.length < 8 || value.length > 255) ? message : undefined;

const validateCountry = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(2), (0, _reactAdmin.maxLength)(2), isCountryCode()];
exports.validateCountry = validateCountry;
const validateEmail = [(0, _reactAdmin.email)()];
exports.validateEmail = validateEmail;
const validateURI = [isURI()];
exports.validateURI = validateURI;
const validateInteger = [(0, _reactAdmin.number)(), (0, _reactAdmin.minValue)(0)];
exports.validateInteger = validateInteger;
const validateKeywordAlpha = [(0, _reactAdmin.required)(), isKeywordAlphaNumeric()];
exports.validateKeywordAlpha = validateKeywordAlpha;
const validateUsername = [(0, _reactAdmin.required)(), isBlankorMin4Upto32(), isKeywordAlphaNumericLC()];
exports.validateUsername = validateUsername;
const validateName = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(4), (0, _reactAdmin.maxLength)(255), isNameOK()];
exports.validateName = validateName;
const validateNameGeneral = [(0, _reactAdmin.required)(), isNameOK()];
exports.validateNameGeneral = validateNameGeneral;
const validateNameShort = [(0, _reactAdmin.required)(), isBlankorUpto64(), isNameOK()];
exports.validateNameShort = validateNameShort;
const validatePositive = [(0, _reactAdmin.number)(), (0, _reactAdmin.minValue)(1)];
exports.validatePositive = validatePositive;

const validateNumMax = max => [(0, _reactAdmin.number)(), (0, _reactAdmin.minValue)(1), (0, _reactAdmin.maxValue)(max)];

exports.validateNumMax = validateNumMax;
const validateSelected = [hasSelection()];
exports.validateSelected = validateSelected;
const validate32String = [isBlankorMin4Upto32()];
exports.validate32String = validate32String;
const validate64String = [isBlankorUpto64()];
exports.validate64String = validate64String;
const validate255String = [isBlankorUpto255()];
exports.validate255String = validate255String;
const validateRequired32String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(2), (0, _reactAdmin.maxLength)(32)];
exports.validateRequired32String = validateRequired32String;
const validateRequired96String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(2), (0, _reactAdmin.maxLength)(96)];
exports.validateRequired96String = validateRequired96String;
const validateRequired128String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(4), (0, _reactAdmin.maxLength)(128)];
exports.validateRequired128String = validateRequired128String;
const validateRequired255String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(8), (0, _reactAdmin.maxLength)(255)];
exports.validateRequired255String = validateRequired255String;
const validateRequired4096String = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(8), (0, _reactAdmin.maxLength)(4096)];
exports.validateRequired4096String = validateRequired4096String;
const validatePasswordOK = [(0, _reactAdmin.required)(), (0, _reactAdmin.minLength)(8), (0, _reactAdmin.maxLength)(64), hasComplexity()];
exports.validatePasswordOK = validatePasswordOK;