"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.profileEdit = exports.profileCreate = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactAdmin = require("react-admin");

var _constants = require("../lib/constants");

var _validate = require("../lib/validate");

var _raCustom = require("../lib/ra-custom");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const profileCreate = props => {
  const {
    uid
  } = typeof props.location.state !== 'undefined' && props.location.state.record;
  const redirect = uid ? "/person/".concat(uid, "/2") : 'show';
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Create, _extends({}, props, {
    title: "Add Profile Item"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.SimpleForm, {
    redirect: redirect
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "uid",
    reference: "person",
    disabled: true,
    filter: {
      id: sessionStorage.getItem('uid')
    },
    label: "User",
    default_value: uid
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectInput, {
    optionText: "name"
  })), /*#__PURE__*/_react.default.createElement(ProfileItemFields, {
    item: "lang"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    source: "privacy",
    choices: _constants.privacyChoices,
    defaultValue: "public"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    disabled: true,
    source: "status",
    defaultValue: "active"
  })));
};

exports.profileCreate = profileCreate;

const profileEdit = props => {
  const uid = sessionStorage.getItem('uid');
  const redirect = uid ? "/person/".concat(uid, "/2") : '/list';
  return /*#__PURE__*/_react.default.createElement(_reactAdmin.Edit, _extends({}, props, {
    title: /*#__PURE__*/_react.default.createElement(_raCustom.MenuTitle, null)
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.SimpleForm, {
    redirect: redirect
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "uid",
    reference: "person",
    disabled: true,
    filter: {
      id: sessionStorage.getItem('uid')
    },
    label: "User",
    default_value: uid
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectInput, {
    optionText: "name"
  })), /*#__PURE__*/_react.default.createElement(ProfileItemFields, null), /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    source: "privacy",
    choices: _constants.privacyChoices,
    defaultValue: "public"
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    disabled: true,
    source: "status",
    defaultValue: "active"
  })));
};

exports.profileEdit = profileEdit;

const ProfileItemFields = ({
  item,
  record,
  ...props
}) => {
  const val = item ? item : record.item;
  return /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    source: "item",
    choices: _constants.profileChoices,
    defaultValue: val
  }), /*#__PURE__*/_react.default.createElement(_reactAdmin.FormDataConsumer, null, ({
    formData,
    ...rest
  }) => ['lang', 'location', 'pronouns', 'tz'].includes(formData.item) || /*#__PURE__*/_react.default.createElement(_reactAdmin.TextInput, {
    source: "value",
    validate: _validate.validateRequired96String
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.FormDataConsumer, null, ({
    formData,
    ...rest
  }) => formData.item === 'lang' && /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectInput, {
    source: "value",
    choices: _constants.localeChoices,
    validate: _validate.validateSelected
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.FormDataConsumer, null, ({
    formData,
    ...rest
  }) => formData.item === 'pronouns' && /*#__PURE__*/_react.default.createElement(_reactAdmin.SelectInput, {
    source: "value",
    choices: _constants.pronounChoices,
    validate: _validate.validateSelected
  })), /*#__PURE__*/_react.default.createElement(_reactAdmin.FormDataConsumer, null, ({
    formData,
    ...rest
  }) => formData.item === 'location' && /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "location_id",
    reference: "location",
    validate: _validate.validateSelected
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    optionText: "name"
  }))), /*#__PURE__*/_react.default.createElement(_reactAdmin.FormDataConsumer, null, ({
    formData,
    ...rest
  }) => formData.item === 'tz' && /*#__PURE__*/_react.default.createElement(_reactAdmin.ReferenceInput, {
    source: "tz_id",
    reference: "tz",
    label: "Timezone",
    validate: _validate.validateSelected
  }, /*#__PURE__*/_react.default.createElement(_reactAdmin.AutocompleteInput, {
    optionText: "name"
  }))));
};

var _default = profileCreate;
exports.default = _default;