"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactAdmin = require("react-admin");

var _reactRouterDom = require("react-router-dom");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactFinalForm = require("react-final-form");

var _core = require("@material-ui/core");

var _raCore = require("ra-core");

var _facebookLogo = _interopRequireDefault(require("../images/facebook-logo.png"));

var _githubLogo = _interopRequireDefault(require("../images/github-logo.png"));

var _googleLogo = _interopRequireDefault(require("../images/google-logo.png"));

var _twitterLogo = _interopRequireDefault(require("../images/twitter-logo.png"));

var _constants = require("../lib/constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const useStyles = (0, _core.makeStyles)(theme => ({
  button: {
    width: '100%',
    marginTop: theme.spacing(1)
  },
  icon: {
    marginRight: theme.spacing(1)
  }
}), {
  name: 'RaLoginButton'
});

const Input = ({
  meta: {
    touched,
    error
  },
  // eslint-disable-line react/prop-types
  input: inputProps,
  // eslint-disable-line react/prop-types
  ...props
}) => /*#__PURE__*/_react.default.createElement(_core.TextField, _extends({
  error: !!(touched && error),
  helperText: touched && error
}, inputProps, props, {
  fullWidth: true
}));

function LoginButton({
  redirectTo,
  ...props
}) {
  const [loading, setLoading] = (0, _reactAdmin.useSafeSetState)(false);
  const [askPassword, setAskPassword] = (0, _reactAdmin.useSafeSetState)(true);
  const [askTOTP, setAskTOTP] = (0, _reactAdmin.useSafeSetState)(false);
  const login = (0, _reactAdmin.useLogin)();
  const history = (0, _reactRouterDom.useHistory)();
  const translate = (0, _reactAdmin.useTranslate)();
  const notify = (0, _raCore.useNotify)();
  const classes = useStyles(props);

  const handleLoginLocal = (code, state, otp) => {
    setLoading(true);
    login({
      code,
      state,
      otp
    }).catch(error => {});
  };

  const handleLoginOAuth = (method, code, state) => {
    setLoading(true);
    login({
      method,
      state
    }).catch(error => {});
  };

  function logo(method) {
    switch (method) {
      case 'facebook':
        return _facebookLogo.default;

      case 'github':
        return _githubLogo.default;

      case 'google':
        return _googleLogo.default;

      case 'twitter':
        return _twitterLogo.default;

      default:
        return null;
    }
  }

  const loadingProgress = /*#__PURE__*/_react.default.createElement(_core.CircularProgress, {
    className: classes.icon,
    size: 18,
    thickness: 2
  });

  (0, _react.useEffect)(() => {
    const {
      searchParams
    } = new URL(window.location.href);
    const code = searchParams.get('code');
    const state = searchParams.get('state');

    if (code && state) {
      handleLoginLocal(code, state, null);
    } // TODO learn how to write this properly
    // eslint-disable-next-line react-hooks/exhaustive-deps

  }, []);

  const validate = values => {
    const errors = {
      username: undefined,
      password: undefined
    };
    const digits = new RegExp('^[0-9]+$');
    const alphanum = new RegExp('^[0-9a-z]+$');

    if (!values.username) {
      errors.username = translate('ra.validation.required');
    }

    if (askPassword && !values.password) {
      errors.password = translate('ra.validation.required');
    }

    if (askTOTP && !values.otp) {
      errors.otp = translate('ra.validation.required');
    }

    if (values.otp && values.otp.length !== 6 && values.otp.length !== 8) {
      errors.otp = 'Length must be 6 or 8';
    }

    if (values.otp && values.otp.length === 6 && !digits.test(values.otp)) {
      errors.otp = 'Enter 6 digits';
    }

    if (values.otp && values.otp.length === 8 && !alphanum.test(values.otp)) {
      errors.otp = 'Enter 8 lowercase letters or digits';
    }

    return errors;
  };

  class AuthButtons extends _react.default.Component {
    constructor(props) {
      super(props);
      this.state = {
        data: null
      };
    }

    componentDidMount() {
      fetch(_constants.apiUrl + '/auth_methods').then(response => response.json()).then(data => this.setState({
        methods: data.items,
        policies: data.policies
      }));
    }

    render() {
      const {
        methods,
        policies
      } = this.state;
      const buttons = [];

      if (methods) {
        if (methods.includes('local') && ['open', 'onrequest'].includes(policies['login_internal'])) {
          buttons.push( /*#__PURE__*/_react.default.createElement("div", {
            key: "create"
          }, /*#__PURE__*/_react.default.createElement(_core.Button, _extends({}, props, {
            onClick: () => history.push('/account/create?forgot=false'),
            variant: "contained",
            color: "primary",
            disabled: loading,
            className: classes.button
          }), loading && loadingProgress, translate('ra.action.create'), " ", translate('ra.auth.username'))));
        }

        for (const method of methods) {
          if (!['ldap', 'local'].includes(method)) {
            buttons.push( /*#__PURE__*/_react.default.createElement("div", {
              key: method
            }, /*#__PURE__*/_react.default.createElement(_core.Button, _extends({}, props, {
              onClick: () => handleLoginOAuth(method),
              variant: "contained",
              color: "primary",
              disabled: loading,
              className: classes.button
            }), loading && loadingProgress, logo(method) && /*#__PURE__*/_react.default.createElement(_core.Avatar, {
              src: logo(method),
              className: classes.avatar
            }), translate('ra.auth.sign_in'), " with ", method)));
          }
        }
      }

      return /*#__PURE__*/_react.default.createElement("div", null, buttons);
    }

  }

  const submit = values => {
    setLoading(true);
    login(values, redirectTo).then(() => {
      setLoading(false);
    }).catch(error => {
      setLoading(false);

      if (error.message === 'pendingtotp') {
        setAskTOTP(true);
        setAskPassword(false);
        error.message = 'OTP ' + translate('ra.validation.required');
      }

      notify(typeof error === 'string' ? error : typeof error === 'undefined' || !error.message ? 'ra.auth.sign_in_error' : error.message, 'warning', {
        _: typeof error === 'string' ? error : error && error.message ? error.message : undefined
      });
    });
  };

  return /*#__PURE__*/_react.default.createElement(_reactFinalForm.Form, {
    onSubmit: submit,
    validate: validate,
    render: ({
      handleSubmit
    }) => /*#__PURE__*/_react.default.createElement("form", {
      onSubmit: handleSubmit,
      noValidate: true
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: classes.form
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: classes.input
    }, /*#__PURE__*/_react.default.createElement(_reactFinalForm.Field, {
      autoFocus: true,
      id: "username",
      name: "username",
      component: Input,
      label: translate('ra.auth.username'),
      disabled: loading
    })), /*#__PURE__*/_react.default.createElement("div", {
      className: classes.input
    }, /*#__PURE__*/_react.default.createElement(_reactFinalForm.Field, {
      id: "password",
      name: "password",
      component: Input,
      label: translate('ra.auth.password'),
      type: "password",
      disabled: loading || !askPassword,
      autoComplete: "current-password"
    })), askTOTP && /*#__PURE__*/_react.default.createElement("div", {
      className: classes.input
    }, /*#__PURE__*/_react.default.createElement(_reactFinalForm.Field, {
      autoFocus: true,
      id: "otp",
      name: "otp",
      component: Input,
      label: "Access Token",
      disabled: loading
    }))), /*#__PURE__*/_react.default.createElement(_core.CardActions, null, /*#__PURE__*/_react.default.createElement(_core.ButtonGroup, {
      fullWidth: true,
      orientation: "vertical"
    }, /*#__PURE__*/_react.default.createElement(_core.Button, {
      variant: "contained",
      type: "submit",
      color: "primary",
      disabled: loading,
      className: classes.button
    }, loading && /*#__PURE__*/_react.default.createElement(_core.CircularProgress, {
      className: classes.icon,
      size: 18,
      thickness: 2
    }), translate('ra.auth.sign_in')), /*#__PURE__*/_react.default.createElement("br", null), /*#__PURE__*/_react.default.createElement(AuthButtons, null))))
  });
}

;
LoginButton.propTypes = {
  redirectTo: _propTypes.default.string
};
LoginButton.defaultProps = {
  redirectTo: '/'
};
var _default = LoginButton;
exports.default = _default;