"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactAdmin = require("react-admin");

var _raCore = require("ra-core");

var _reactFinalForm = require("react-final-form");

var _reactRouterDom = require("react-router-dom");

var _core = require("@material-ui/core");

var _constants = require("../lib/constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var QRCode = require('qrcode.react');

class MFAGenerate extends _react.default.Component {
  constructor(props) {
    super(props);
    this.state = {
      data: null
    };
  }

  componentDidMount() {
    const uid = sessionStorage.getItem('uid');
    const token = sessionStorage.getItem('token');
    const request = new Request(_constants.apiUrl + '/auth_totp', {
      headers: new Headers({
        Accept: 'application/json',
        Authorization: 'Basic ' + btoa(uid + ':' + token)
      })
    }); // TODO handle errors

    fetch(request).then(response => response.json()).then(data => this.setState({
      uri: data.uri,
      nonce: data.jti
    }));
  }

  render() {
    const {
      nonce,
      uri
    } = this.state;
    sessionStorage.setItem('nonce', nonce);

    if (uri) {
      return /*#__PURE__*/_react.default.createElement("div", null, "Scan this QR code on your authenticator app", /*#__PURE__*/_react.default.createElement("p", null), /*#__PURE__*/_react.default.createElement(QRCode, {
        renderAs: 'svg',
        value: uri,
        size: 192
      }));
    } else {
      return '';
    }
  }

}

const useStyles = (0, _core.makeStyles)(theme => ({
  button: {
    width: '100%',
    marginTop: theme.spacing(1)
  },
  icon: {
    marginRight: theme.spacing(1)
  }
}), {
  name: 'MFARegister'
});

const Input = ({
  meta: {
    touched,
    error
  },
  // eslint-disable-line react/prop-types
  input: inputProps,
  // eslint-disable-line react/prop-types
  ...props
}) => /*#__PURE__*/_react.default.createElement(_core.TextField, _extends({
  error: !!(touched && error),
  helperText: touched && error
}, inputProps, props));

const MFA = ({
  redirectTo,
  ...props
}) => {
  const classes = useStyles(props);
  const [loading, setLoading] = (0, _reactAdmin.useSafeSetState)(false);
  const [registered, setRegistered] = (0, _reactAdmin.useSafeSetState)(false);
  const [totp_toggle, setTotpToggle] = (0, _reactAdmin.useSafeSetState)(false);
  const [backup_codes, setBackupCodes] = (0, _reactAdmin.useSafeSetState)(null);
  const [redir, setRedir] = (0, _reactAdmin.useSafeSetState)(redirectTo);
  const history = (0, _reactRouterDom.useHistory)();
  const notify = (0, _raCore.useNotify)();
  const translate = (0, _reactAdmin.useTranslate)();
  const uid = sessionStorage.getItem('uid');
  const token = sessionStorage.getItem('token');
  const authHeaders = new Headers({
    Accept: 'application/json',
    Authorization: 'Basic ' + btoa(uid + ':' + token),
    'Content-Type': 'application/json'
  });

  const validate = values => {
    const errors = {
      otp_first: undefined
    };
    const digits = new RegExp('^[0-9]+$');

    if (!values.otp_first) {
      errors.otp_first = translate('ra.validation.required');
    }

    if (values.otp_first && (values.otp_first.length !== 6 || !digits.test(values.otp_first))) {
      errors.otp_first = 'Enter 6 digits';
    }

    return errors;
  };

  function register({
    otp_first
  }) {
    const nonce = sessionStorage.getItem('nonce');
    const auth = sessionStorage.getItem('auth');
    sessionStorage.removeItem('nonce');
    const request = new Request(_constants.apiUrl + '/auth_totp', {
      method: 'POST',
      body: JSON.stringify({
        otp_first,
        nonce
      }),
      headers: authHeaders
    });
    return fetch(request).then(response => {
      if (!response.ok) {
        throw Error(response.json().message);
      }

      return response.json();
    }).then(json => {
      setBackupCodes(json.backup_codes.join("\n"));
      setRegistered(true);

      if (auth && auth.includes('mfarequired')) {
        setRedir('/logout');
        sessionStorage.removeItem('auth');
        sessionStorage.removeItem('token');
      }

      return json;
    });
  }

  function isRegistered() {
    const request = new Request(_constants.apiUrl + "/account?filter={\"uid\":\"".concat(uid, "\"}"), {
      headers: authHeaders
    }); // TODO handle errors

    return fetch(request).then(response => response.json()).then(json => {
      setRegistered(json.items[0].totp); // TODO: maybe allow a user to toggle MFA off

      if (registered) {
        setTotpToggle(true);
      }
    }).catch(console.error);
  }

  const submit = values => {
    setLoading(true);
    register(values, redirectTo).then(() => {
      setLoading(false);
    }).catch(error => {
      setLoading(false);
      notify(typeof error === 'string' ? error : typeof error === 'undefined' || !error.message ? 'ra.auth.sign_in_error' : error.message, 'warning', {
        _: typeof error === 'string' ? error : error && error.message ? error.message : undefined
      });
    });
  }; // TODO this apparently re-invokes endpoint each reference to var registered,
  //and does it 5+ times


  isRegistered(); // TODO: deal with warning
  // Failed prop type: Invalid prop `children` supplied to `ForwardRef(CardContent)`, expected a ReactNode.

  return /*#__PURE__*/_react.default.createElement(_core.Card, null, /*#__PURE__*/_react.default.createElement(_reactAdmin.Title, {
    title: "MFA"
  }), /*#__PURE__*/_react.default.createElement(_core.CardContent, null, totp_toggle && (registered || /*#__PURE__*/_react.default.createElement(MFAGenerate, null))), /*#__PURE__*/_react.default.createElement(_core.CardContent, null, /*#__PURE__*/_react.default.createElement(_reactFinalForm.Form, {
    onSubmit: submit,
    validate: validate,
    render: ({
      handleSubmit
    }) => /*#__PURE__*/_react.default.createElement("form", {
      onSubmit: handleSubmit,
      noValidate: true
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: classes.form
    }, /*#__PURE__*/_react.default.createElement("div", {
      className: classes.input
    }, "Enable TOTP? ", /*#__PURE__*/_react.default.createElement(_core.Switch, {
      id: "totp_enabled",
      name: "totp_enabled",
      onChange: (_, value) => setTotpToggle(value),
      disabled: loading,
      checked: totp_toggle
    })), totp_toggle && (registered || /*#__PURE__*/_react.default.createElement("div", {
      className: classes.input
    }, /*#__PURE__*/_react.default.createElement(_reactFinalForm.Field, {
      autoFocus: true,
      id: "otp_first",
      name: "otp_first",
      label: "Enter Verification Code",
      disabled: loading,
      component: Input
    })))), backup_codes && /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(ShowBackupCodes, {
      backup_codes: backup_codes
    })), /*#__PURE__*/_react.default.createElement(_core.CardActions, null, /*#__PURE__*/_react.default.createElement(_core.Button, {
      variant: "contained",
      type: "submit",
      color: "primary",
      disabled: loading,
      onClick: () => (!totp_toggle || registered) && history.push(redir),
      className: classes.icon
    }, !totp_toggle || registered ? translate('ra.action.close') : translate('ra.action.confirm'))))
  })));
};

const ShowBackupCodes = ({
  backup_codes
}) => /*#__PURE__*/_react.default.createElement(_core.Card, null, /*#__PURE__*/_react.default.createElement(_reactAdmin.Title, {
  title: " - Your backup access tokens"
}), /*#__PURE__*/_react.default.createElement(_core.CardContent, null, /*#__PURE__*/_react.default.createElement(_core.Box, {
  color: "primary.main",
  bgcolor: "#70ff70",
  fontFamily: "Monospace",
  p: {
    xs: 2,
    sm: 3,
    md: 4
  },
  style: {
    whiteSpace: "pre-line"
  }
}, backup_codes), /*#__PURE__*/_react.default.createElement("br", null), /*#__PURE__*/_react.default.createElement("br", null), "Save these single-use codes into a password vault - they cannot be displayed again", /*#__PURE__*/_react.default.createElement("br", null)));

MFA.defaultProps = {
  redirectTo: "/account_password/".concat(sessionStorage.getItem('uid'))
};
var _default = MFA;
exports.default = _default;